

angular.module('starter.controllers')
    .directive('tdppie', function ($parse) {
        'use strict';
        return {
            restrict: 'E',
            template: '<div></div>',
            link: function (scope, element, attrs) {
                attrs.chart = new Highcharts.chart(element[0], {
                    chart: {
                        type: 'pie'
                    },
                    title: {
                        text: attrs.title
                    },
                    dataLabels: {
                        enabled: true
                    },
                    colors: ['#3498DB', '#F39C12', '#A6ACAF', '#58D68D', '#884EA0',
                        '#212F3D', '#A04000'],
                    tooltip: {
                        pointFormat: '<b>{point.y:.0f}</b>'
                    },
                    plotOptions: {
                        pie: {
                            allowPointSelect: true,
                            cursor: 'pointer',
                            showInLegend: true,
                            dataLabels: {
                                enabled: true,
                                distance: -30,
                                format: '{point.y:.0f}',
                                style: {
                                    color: (Highcharts.theme && Highcharts.theme.contrastTextColor) || 'black'
                                }
                            }
                        }
                    }
                });

                scope.$watch(function () {
                    return attrs.categories;
                }, function () {
                    if (attrs.chart.xAxis.length === 0) {
                        attrs.chart.addAxis($parse(attrs.categories)(scope));
                    } else {
                        attrs.chart.xAxis[0].setCategories($parse(attrs.categories)(scope));
                    }
                });

                scope.$watch(function () {
                    return attrs.title;
                }, function () {
                    attrs.chart.setTitle({ text: attrs.title });
                });



                scope.$watch(function () {
                    return attrs.series;
                }, function () {
                    var i;

                    for (i = 0; i < $parse(attrs.series)(scope).length; i++) {
                        if (attrs.chart.series[i]) {
                            attrs.chart.series[0].setData($parse(attrs.series)(scope)[i].data);
                        } else {
                            attrs.chart.addSeries($parse(attrs.series)(scope)[i]);
                        }
                    }

                    if (i < attrs.chart.series.length - 1) {
                        var seriesLength = attrs.chart.series.length - 1;

                        for (var j = seriesLength; j > i; j--) {
                            attrs.chart.series[j].remove();
                        }
                    }

                });
            }
        };
    })

    .directive('highchartsColumns', function ($parse) {
        'use strict';
        return {
            restrict: 'E',
            template: '<div></div>',
            link: function (scope, element, attrs) {
                attrs.chart = new Highcharts.chart(element[0], {
                    chart: {
                        type: 'column'
                    },
                    title: {
                        text: attrs.title
                    },
                    dataLabels: {
                        enabled: true
                    },
                    colors: ['#3498DB', '#F39C12', '#A6ACAF', '#58D68D', '#884EA0',
                        '#212F3D', '#A04000'],
                    plotOptions: {
                        column: {
                            stacking: 'normal',
                            dataLabels: {
                                enabled: true,
                            }
                        },
                        line: {
                            dataLabels: {
                                enabled: true,
                            }
                        }
                    }
                });

                scope.$watch(function () {
                    return attrs.categories;
                }, function () {
                    if (attrs.chart.xAxis.length === 0) {
                        attrs.chart.addAxis($parse(attrs.categories)(scope));
                    } else {
                        attrs.chart.xAxis[0].setCategories($parse(attrs.categories)(scope));
                    }
                });

                scope.$watch(function () {
                    return attrs.title;
                }, function () {
                    attrs.chart.setTitle({ text: attrs.title });
                });



                scope.$watch(function () {
                    return attrs.series;
                }, function () {
                    var i;

                    for (i = 0; i < $parse(attrs.series)(scope).length; i++) {
                        if (attrs.chart.series[i]) {
                            attrs.chart.series[0].setData($parse(attrs.series)(scope)[i].data);
                        } else {
                            attrs.chart.addSeries($parse(attrs.series)(scope)[i]);
                        }
                    }

                    if (i < attrs.chart.series.length - 1) {
                        var seriesLength = attrs.chart.series.length - 1;

                        for (var j = seriesLength; j > i; j--) {
                            attrs.chart.series[j].remove();
                        }
                    }

                });
            }
        };
    })
    .controller('TDPCtrl', function ($scope, $filter, getTDPService, $stateParams) {
        $scope.xAxisValue = [];
        $scope.wrData = [];
        $scope.wrtodate = $filter('date')((new Date()), "yyyy-MM-dd");
        $scope.wrfromdate = $filter('date')((new Date((new Date()) - 24 * 10 * 60 * 60 * 1000)), "yyyy-MM-dd");
        $scope.tdptitle = "";
        $scope.tdptitleincout = "";
        $scope.agingData = [];
        $scope.severityData = [];

        $scope.SelectedLOB = $stateParams.LOB.replace(":", "");

        $scope.LoadData = function () {

            $scope.xAxisValue = [];
            $scope.wrData = [];
            $scope.tdpData = [];
            $scope.tdpCategory = [];

            var wrtodate = "";
            var wrfromdate = "";
            wrtodate = document.getElementById("tdptodate" + $scope.SelectedLOB + "").value;
            wrfromdate = document.getElementById("tdpfromdate" + $scope.SelectedLOB + "").value;

            console.log(wrfromdate);
            console.log(wrtodate);

            if (wrtodate == "" || wrtodate == null) {
                $scope.wrtodate = $filter('date')((new Date()), "yyyy-MM-dd");
                $scope.wrfromdate = $filter('date')((new Date((new Date()) - 24 * 10 * 60 * 60 * 1000)), "yyyy-MM-dd");
            }
            else {
                $scope.wrtodate = wrtodate;
                $scope.wrfromdate = wrfromdate;
            }

            console.log($scope.wrtodate);
            console.log($scope.wrfromdate);
            var LOB = $scope.SelectedLOB.toLowerCase();
            console.log(LOB);
            $scope.showLoading();
            var tdpService = getTDPService.startService($scope.wrfromdate, $scope.wrtodate, LOB);
            tdpService.then(
                function (success) {
                    console.log(success);
                    jsonStructure(success, LOB);
                    jsonStructureTDPStatus(success, LOB);
                    jsonStructureTDPCount(success);
                    jsonStructureTDPSev(success);
                    doOnOrientationChange();
                    $scope.hideLoading();
                });

            function jsonStructure(jsondata, LOB) {
                var groupedJson = [];
                var dateRange = [];
                var category = [];

                $.each(jsondata, function (i, obj) {
                    var sod = 0;
                    var handled = 0;
                    var backlog = 0;
                    var incoming = 0;
                    var outgoing = 0;
                    if (!dateRange.includes(obj.insertDate)) {
                        $.each(jsondata, function (i, objinner) {
                            if (obj.insertDate == objinner.insertDate) {
                                sod = sod + objinner.sod;
                                handled = handled + objinner.outgoing;
                                backlog = backlog + objinner.backlog;
                                backlogtrb = backlog;
                                incoming = incoming + objinner.incoming;
                            }
                        });
                        var jsonObjtmp = {
                            Insert_date: obj.insertDate,
                            sod: sod,
                            handled: handled,
                            backlog: backlog,
                            incoming: incoming,
                            teamName: obj.teamName
                        };
                        groupedJson.push(jsonObjtmp);
                        category.push(obj.insertDate.split(" ", 1))
                        dateRange.push(obj.insertDate);
                    }
                });

                var incoming;
                var sod;
                var handled;
                var backlog;
                incoming = {
                    "type": "column",
                    "name": "Incoming",
                    "data": []

                }

                sod = {
                    "type": "column",
                    "name": "SOD",
                    "data": []

                }
                handled = {
                    "type": "column",
                    "name": "Handled",
                    "data": []

                }
                backlog = {
                    "type": "line",
                    "name": "Backlog",
                    "data": []

                }

                var printData = [];
                $.each(groupedJson, function (ix, obj) {
                    incoming.data.push(obj.incoming);
                    sod.data.push(obj.sod);
                    handled.data.push(obj.handled);
                    backlog.data.push(obj.backlog);
                });

                //console.log('adding printdata');
                printData.push(sod);
                printData.push(incoming);
                printData.push(handled);
                printData.push(backlog);

                var varTrb = category.map(function (date) {
                    let
                        formatOptions = {
                            month: '2-digit',
                            day: '2-digit',
                            year: 'numeric'
                        };
                    return new Date(date).toLocaleDateString(undefined, formatOptions);
                });

                $scope.wrData = printData;
                $scope.xAxisValue = varTrb;
                $scope.tdptitleincout = " TDP Incoming/Outgoing";
            }




            window.addEventListener('orientationchange', doOnOrientationChange);
        }
        function doOnOrientationChange() {
            var width = window.screen.availWidth;
            if (width >= 767) {
                $('highcharts-columns').css({ 'display': 'block', 'width': width - 280 });
                $('highcharts-column').css({ 'display': 'block', 'width': width - 280 });
                $('tdppie').css({ 'display': 'block', 'width': width - 280 });
            }
            else {
                $('highcharts-columns').css({ 'display': 'block', 'width': width });
                $('highcharts-column').css({ 'display': 'block', 'width': width });
                $('tdppie').css({ 'display': 'block', 'width': width });
            }
        }

        function jsonStructureTDPStatus(jsondata, LOB) {
            var groupedJson = [];
            var dateRange = [];
            var category = [];
            $.each(jsondata, function (i, obj) {
                var retestComplete = 0;
                var openUnderInvestigation = 0;
                var underTesting = 0;
                var retestBlocked = 0;
                var retestFailed = 0;
                var returnedRejected = 0;
                if (!dateRange.includes(obj.insertDate)) {
                    $.each(jsondata, function (i, objinner) {
                        if (obj.insertDate == objinner.insertDate) {
                            retestComplete = retestComplete + objinner.retestComplete;
                            openUnderInvestigation = openUnderInvestigation + objinner.openUnderInvestigation;
                            underTesting = underTesting + objinner.underTesting;
                            retestBlocked = retestBlocked + objinner.retestBlocked;
                            retestFailed = retestFailed + objinner.retestFailed;
                            returnedRejected = returnedRejected + objinner.returnedRejected;
                        }
                    });
                    var jsonObjtmp = {
                        Insert_date: obj.insertDate,
                        retestComplete: retestComplete,
                        openUnderInvestigation: openUnderInvestigation,
                        underTesting: underTesting,
                        retestBlocked: retestBlocked,
                        retestFailed: retestFailed,
                        returnedRejected: returnedRejected
                    };
                    groupedJson.push(jsonObjtmp);
                    category.push(obj.insertDate.split(" ", 1))
                    dateRange.push(obj.insertDate);
                }
            });

            var retestBlocked;
            var retestComplete;
            var openUnderInvestigation;
            var underTesting;
            var retestFailed;
            var returnedRejected;

            retestBlocked = {
                "type": "column",
                "name": "Retest Blocked",
                "data": []

            }

            retestFailed = {
                "type": "column",
                "name": "Retest Failed",
                "data": []

            }

            returnedRejected = {
                "type": "column",
                "name": "Returned Rejected",
                "data": []

            }

            retestComplete = {
                "type": "column",
                "name": "Retest Complete",
                "data": []

            }
            openUnderInvestigation = {
                "type": "column",
                "name": "Open Under Investigation",
                "data": []

            }
            underTesting = {
                "type": "column",
                "name": "Under Testing",
                "data": []

            }

            var printData = [];
            $.each(groupedJson, function (ix, obj) {
                retestBlocked.data.push(obj.retestBlocked);
                retestComplete.data.push(obj.retestComplete);
                openUnderInvestigation.data.push(obj.openUnderInvestigation);
                underTesting.data.push(obj.underTesting);
                retestFailed.data.push(obj.retestFailed);
                returnedRejected.data.push(obj.returnedRejected);
            });

            //console.log('adding printdata');
            printData.push(retestComplete);
            printData.push(retestBlocked);
            printData.push(openUnderInvestigation);
            printData.push(underTesting);
            printData.push(retestFailed);
            printData.push(returnedRejected);

            var varTdp = category.map(function (date) {
                let
                    formatOptions = {
                        month: '2-digit',
                        day: '2-digit',
                        year: 'numeric'
                    };
                return new Date(date).toLocaleDateString(undefined, formatOptions);
            });
            console.log('count by status', printData);
            //drawchartsGeneric(id, printData, varTrb, lables, graphName, true, true);
            $scope.tdpData = printData;
            $scope.tdpCategory = varTdp;
            $scope.tdptitle = "TDP Count By Status";
        }

        function jsonStructureTDPCount(jsondata) {
            var category = [];
            var dateRange = [];

            var Current_date = new Date();

            var Month = Current_date.getMonth() + 1;
            var MON;
            if (Month < 10)
                MON = '0' + Month;
            else
                MON = Month;

            var DD;
            if (Current_date.getDate() < 10)
                DD = '0' + Current_date.getDate();
            else
                DD = Current_date.getDate();

            var Today_DATE = Current_date.getFullYear() + '-' + MON + '-' + DD;


            var less5 = {
                "type": "column",
                "name": "TDP Aging",
                "data": []
            };
            var sixto10 = {
                "type": "column",
                "name": "6 to 10",
                "data": []
            };
            var d11to15 = {
                "type": "column",
                "name": "11 to 15",
                "data": []
            };

            var d16to20 = {
                "type": "column",
                "name": "16 to 20",
                "data": []
            };

            var grt20 = {
                "type": "column",
                "name": ">20",
                "data": []
            };



            var days0to5 = 0;
            var days6to10 = 0;
            var days11to15 = 0;
            var days16to20 = 0;
            var days21toMax = 0;
            var Series = [];
            //console.log('Today_DATE'+Today_DATE);


            $.each(jsondata, function (i, objinner) {
                if (Today_DATE == objinner.insertDate.split(' ')[0]) {
                    days0to5 = days0to5 + objinner.days0to5;
                    days6to10 = days6to10 + objinner.days6to10;
                    days11to15 = days11to15 + objinner.days11to15;
                    days16to20 = days16to20 + objinner.days16to20;
                    days21toMax = days21toMax + objinner.days21toMax;
                }

            });
            less5.data.push(days0to5);
            less5.data.push(days6to10);
            less5.data.push(days11to15);
            less5.data.push(days16to20);
            less5.data.push(days21toMax);

            category.push("<5");
            category.push(sixto10.name);
            category.push(d11to15.name);
            category.push(d16to20.name);
            category.push(grt20.name);


            Series.push(less5);

            $scope.agingData = Series;
            $scope.agingCategory = category;
            $scope.tdptitleaging = " TDP Count By Aging";

            // drawchartsGeneric(id, Series, category, lables, graphName, false, false);

        }

        function jsonStructureTDPSev(jsondata) {
            var groupedJson = [];
            var dateRange = [];
            var category = [];
            var backlogtrb;
            $.each(jsondata, function (i, obj) {
                var severity1 = 0;
                var severity2 = 0;
                var severity3 = 0;
                if (!dateRange.includes(obj.insertDate)) {
                    $.each(jsondata, function (i, objinner) {
                        if (obj.insertDate == objinner.insertDate) {
                            severity1 = severity1 + objinner.severity1;
                            severity2 = severity2 + objinner.severity2;
                            severity3 = severity3 + objinner.severity3;
                        }
                    });
                    var jsonObjtmp = {
                        Insert_date: obj.insertDate,
                        severity1: severity1,
                        severity2: severity2,
                        severity3: severity3
                    };
                    groupedJson.push(jsonObjtmp);
                    category.push(obj.insertDate.split(" ", 1))
                    dateRange.push(obj.insertDate);
                }
            });

            var sev1;
            var sev2;
            var sev3;
            sev1 = {
                "name": "Severity 1",
                "y": 0

            }

            sev2 = {
                "name": "Severity 2",
                "y": 0

            }
            sev3 = {
                "name": "Severity 3",
                "y": 0

            }

            var series = [{
                name: 'Severity',
                colorByPoint: true,
                data: []
            }]


            var printData = [];
            $.each(groupedJson, function (ix, obj) {
                sev1.y = obj.severity1;
                sev2.y = obj.severity2;
                sev3.y = obj.severity3;
            });

            //console.log('adding seriesdata');
            series[0].data.push(sev1);
            series[0].data.push(sev2);
            series[0].data.push(sev3);
            console.log('pie series data', series);
            //drawPieChart(id, series, category, lables, graphName, false, true);

            $scope.severityData = series;
            $scope.severityCategory = category;
            $scope.tdptitleseverity = " TDP Count By Severity";

        }
        doOnOrientationChange();
        $scope.$on('$ionicView.enter', function (e) {
            doOnOrientationChange();
            $scope.LoadData();

        });


    });








