angular.module('starter.controllers')
    .directive('highchartsColumn', function ($parse) {
        'use strict';
        return {
            restrict: 'E',
            template: '<div></div>',
            link: function (scope, element, attrs) {
                attrs.chart = new Highcharts.chart(element[0], {
                    chart: {
                        type: 'column',
                     
                    },

                    title: {
                        text: attrs.title
                    },
                    dataLabels: {
                        enabled: true
                    },
                    colors: ['#3498DB', '#F39C12', '#A6ACAF', '#58D68D', '#884EA0',
                        '#212F3D', '#A04000'],
                    plotOptions: {
                        column: {
                            dataLabels: {
                                enabled: true,
                            }
                        },
                        line: {
                            dataLabels: {
                                enabled: true,
                            }
                        }

                    }
                });

                scope.$watch(function () {
                    return attrs.categories;
                }, function () {
                    if (attrs.chart.xAxis.length === 0) {
                        attrs.chart.addAxis($parse(attrs.categories)(scope));
                    } else {
                        attrs.chart.xAxis[0].setCategories($parse(attrs.categories)(scope));
                    }
                });

                scope.$watch(function () {
                    return attrs.title;
                }, function () {
                    attrs.chart.setTitle({ text: attrs.title });
                });
                scope.$watch(function () {
                    return attrs.series;
                }, function () {
                    var i;

                    for (i = 0; i < $parse(attrs.series)(scope).length; i++) {
                        if (attrs.chart.series[i]) {
                            attrs.chart.series[0].setData($parse(attrs.series)(scope)[i].data);
                        } else {
                            attrs.chart.addSeries($parse(attrs.series)(scope)[i]);
                        }
                    }

                    if (i < attrs.chart.series.length - 1) {
                        var seriesLength = attrs.chart.series.length - 1;

                        for (var j = seriesLength; j > i; j--) {
                            attrs.chart.series[j].remove();
                        }
                    }

                });
            }
        };
    })
    .controller('WebtraxCtrl', function ($scope, $filter, getWebtraxService, $stateParams) {
        $scope.xAxisValue = [];
        $scope.wrData = [];
        $scope.wrtodate = $filter('date')((new Date()), "yyyy-MM-dd");
        $scope.wrfromdate = $filter('date')((new Date((new Date()) - 24 * 10 * 60 * 60 * 1000)), "yyyy-MM-dd");
        $scope.wrtitle = "";
        $scope.SelectedLOB = $stateParams.LOB.replace(":", "");
        $scope.heightLandscape = {};

        $scope.LoadData = function () {
            $scope.xAxisValue = [];
            $scope.wrData = [];
            var wrtodate = "";
            var wrfromdate = "";
            wrtodate = document.getElementById("wrtodate" + $scope.SelectedLOB + "").value;
            wrfromdate = document.getElementById("wrfromdate" + $scope.SelectedLOB + "").value;
            console.log('date for wr is', wrtodate);
            if (wrtodate == "" || wrtodate == null) {
                $scope.wrtodate = $filter('date')((new Date()), "yyyy-MM-dd");
                $scope.wrfromdate = $filter('date')((new Date((new Date()) - 24 * 10 * 60 * 60 * 1000)), "yyyy-MM-dd");
            }
            else {
                $scope.wrtodate = wrtodate;
                $scope.wrfromdate = wrfromdate;
            }

            var LOB = $scope.SelectedLOB.substring(0, 1).toUpperCase() + $scope.SelectedLOB.slice(1).toLowerCase();


            $scope.showLoading();

            var webtraxservice = getWebtraxService.startService($scope.wrfromdate, $scope.wrtodate, LOB);
            webtraxservice.then(
                function (success) {
                    
                    drawChartWr(success);
                    $scope.hideLoading();
                    doOnOrientationChange();
                });

            function drawChartWr(result) {
                var wrData = result;
                var dateID = [];
                var wrgrouped = [];
                var dateCategories = [];

                $scope.title = $scope.SelectedLOB + "Incoming/Outgoing";
                $.each(wrData, function (ix, objout) {
                    var sod = 0
                    var handled = 0
                    var backlog = 0;
                    var incoming = 0;
                    if (!dateID.includes(objout.insertDate)) {
                        $.each(wrData, function (ix, objin) {
                            if (objout.insertDate == objin.insertDate) {
                                sod = sod + objin.startOfDay;
                                handled = handled + objin.outgoing;
                                backlog = backlog + objin.backlogWrCount;
                                incoming = incoming + objin.incoming;

                            }
                        });
                        var jsonobj = {
                            Insert_date: objout.insertDate,
                            SOD: sod,
                            Handled: handled,
                            Backlog: backlog,
                            Incoming: incoming
                        };
                        wrgrouped.push(jsonobj);
                        dateCategories.push(objout.insertDate.split(" ", 1));

                        dateID.push(objout.insertDate);
                    }

                });

                var sod = {
                    "type": "column",
                    "name": "SOD",
                    "data": []

                }

                var incoming = {
                    "type": "column",
                    "name": "Incoming",
                    "data": []

                }
                var Handled = {
                    "type": "column",
                    "name": "Handled",
                    "data": []

                }
                var Backlog = {
                    "type": "line",
                    "name": "Backlog",
                    "data": []

                }
                var printData = [];
                $.each(wrgrouped, function (ix, obj) {
                    sod.data.push(obj.SOD);
                    Handled.data.push(obj.Handled);
                    incoming.data.push(obj.Incoming);
                    Backlog.data.push(obj.Backlog);
                });

                printData.push(sod);
                printData.push(incoming);
                printData.push(Handled);
                printData.push(Backlog);


                var cat1 = dateCategories.map(function (date) {
                    let
                        formatOptions = {
                            month: '2-digit',
                            day: '2-digit',
                            year: 'numeric'
                        };
                    return new Date(date).toLocaleDateString(undefined, formatOptions);
                });
                $scope.wrData = printData;
                $scope.xAxisValue = cat1;
                $scope.title = "Webtrax" + $scope.SelectedLOB;
                $scope.wrtitle = "Webtrax Statistics"
            }
        }
       
        function doOnOrientationChange() {
            console.log('on orientation change')
            var width = window.screen.availWidth;
            console.log('width is ',width)
            if (width >= 767) {
         $('highcharts-column').css({ 'display': 'block', 'width': width-280 });
         console.log('width is 1',width)
          }
            else {
                $('highcharts-column').css({ 'display': 'block', 'width': width });
                console.log('width is 2',width)
               }
        }
        doOnOrientationChange();
        window.addEventListener('orientationchange', doOnOrientationChange);
        $scope.$on('$ionicView.enter', function (e) {
            doOnOrientationChange();
            $scope.LoadData();
        });
    });





